# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler. DO NOT EDIT!
# See https://github.com/eolymp/contracts/tree/main/cmd/protoc-gen-python-esdk for more details.
"""Generated protocol buffer code."""

import urllib.parse
from google.protobuf import symbol_database as _symbol_database

_sym_db = _symbol_database.Default()


class DiscussionServiceClient:
    def __init__(self, transport, url="https://api.eolymp.com"):
        self.transport = transport
        self.url = url

    def DescribeDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DescribeDiscussionOutput"),
            **kwargs,
        )

    def ListDiscussions(self, request, **kwargs):
        path = "/discussions"

        return self.transport.request(
            method="GET",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.ListDiscussionsOutput"),
            **kwargs,
        )

    def CreateDiscussion(self, request, **kwargs):
        path = "/discussions"

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.CreateDiscussionOutput"),
            **kwargs,
        )

    def UpdateDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="PUT",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.UpdateDiscussionOutput"),
            **kwargs,
        )

    def DeleteDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="DELETE",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.DeleteDiscussionOutput"),
            **kwargs,
        )

    def VoteDiscussion(self, request, **kwargs):
        path = "/discussions/"+urllib.parse.quote(request.discussion_id)+"/vote"

        # Cleanup URL parameters to avoid any ambiguity
        request.discussion_id = ""

        return self.transport.request(
            method="POST",
            url=self.url+path,
            request_data=request,
            response_symbol=_sym_db.GetSymbol("eolymp.discussion.VoteDiscussionOutput"),
            **kwargs,
        )

